==> chamilo-1.11.26.zip: chamilo-1.11.26/plugin/vchamilo/lang/french.php <==
<?php
/**
 * @copyright (c) 2014 Valery Fremaux
 * @license GNU General Public License - http://www.gnu.org/copyleft/gpl.html
 * @author Valery Fremaux <valery.fremaux@gmail.com>
 */
$strings['archiverealroot'] = 'Container effectif d\'archives (chemin réel)';
$strings['backtoindex'] = 'Retour aux instances';
$strings['cancel'] = 'Annuler';
$strings['choose'] = 'Choisir une action...';
$strings['closewindow'] = 'Fermer cette fenêtre';
$strings['continue'] = 'Continuer';
$strings['coursefolder'] = 'Répertoire des cours';
$strings['courserealroot'] = 'Container effectif de cours (chemin réel)';
$strings['clearcache'] = 'Vider le cache Twig';
$strings['clearmastercache'] = 'Vider le cache Twig du maître';
$strings['datalocation'] = 'Emplacement des données';
$strings['datapathavailable'] = 'Le répertoire de données est disponible : <br/>';
$strings['datapathnotavailable'] = 'Le répertoire de données existe mais a déjà des fichiers à l\'emplacement <br/>';
$strings['datapathcreated'] = 'Le répertoire de données a été créé :<br/>';
$strings['dbgroup'] = 'Réglages de base de données';
$strings['dbhost'] = 'Hôte de BdD';
$strings['dbpassword'] = 'Mot de passe';
$strings['dbprefix'] = 'Préfix de base';
$strings['dbuser'] = 'Utilisateur de BdD';
$strings['deleteinstances'] = "Désactiver";
$strings['destroyinstances'] = "Détruire";
$strings['edit'] = 'Modifier les paramètres';
$strings['emptysite'] = 'Nouveau site vide';
$strings['enable_virtualisation'] = 'Activer';
$strings['enabled'] = 'Etat';
$strings['enableinstances'] = "Activer";
$strings['enabling'] = 'Activation';
$strings['errormuststartwithcourses'] = 'Le répertoire de cours doit commencer par \'courses_\' pour éviter les collisions de chemin';
$strings['homerealroot'] = 'Container effectif de pages d\'accueil (chemin réel)';
$strings['hostdefinition'] = 'Définition d\'hôte';
$strings['hostlist'] = 'Les sites du réseau';
$strings['institution'] = 'Institution';
$strings['lastcron'] = 'Dernier cron';
$strings['maindatabase'] = 'Nom de BdD';
$strings['manage_instances'] = 'Aller au gestionnaire d\'instances';
$strings['sync_settings'] = 'Synchroniser des réglages';
$strings['deleteifempty'] = 'Supprimer la clef si vide';
$strings['newinstance'] = "Ajouter une instance";
$strings['no'] = 'Non';
$strings['plugin_comment'] = 'Permettre les chamilos virtuels.';
$strings['plugin_title'] = 'Virtualisation de Chamilo';
$strings['proxysettings'] = 'Réglages du Proxy';
$strings['registerinstance'] = "Enregistrer une instance";
$strings['rootweb'] = 'Racine Web';
$strings['savechanges'] = 'Enregistrer les modifications';
$strings['selectall'] = 'Selectionner tout';
$strings['selectnone'] = 'Déselectionner tout';
$strings['setconfigvalue'] = 'Mettre à jour une variable de configuration';
$strings['distributevalue'] = 'Distribuer la configuration';
$strings['sendconfigvalue'] = 'Distribution d\'une valeur de configuration';
$strings['singledatabase'] = 'Base de données unique';
$strings['sitename'] = 'Nom du site';
$strings['snapshotinstance'] = 'Snapshot';
$strings['snapshotmaster'] = 'Snapshot du Chamilo maître';
$strings['statisticsdatabase'] = 'base de données de statistiques';
$strings['successfinishedcapture'] = 'La capture de Chamilo est terminée';
$strings['tableprefix'] = 'Prefixe de table';
$strings['template'] = 'Modèle';
$strings['templating'] = 'Templating';
$strings['testconnection'] = "Test de la connexion";
$strings['testdatapath'] = "Test de l'emplacement de données";
$strings['userpersonaldatabase'] = 'base de données des données personnelles';
$strings['vchamilo'] = 'Chamilo Virtuel';
$strings['vchamilosnapshot1'] = 'ETAPE 1 DE 3 : Les répertoires de snapshot ont été créés. Continuer avec la capture des bases...';
$strings['vchamilosnapshot2'] = 'ETAPE 2 DE 3 : Les bases ont été capturées. Continuer avec la récupération des fichiers d\'usage... Attention, cette étape peut être longue si la plate-forme est fortement chargée en documents...';
$strings['vchamilosnapshot3'] = 'ETAPE 3 DE 3 : Fichiers capturés.';
$strings['withselection'] = "Avec la sélection : ";
$strings['yes'] = 'Oui';

$strings['mysqlcmds'] = 'Emplacement de la commande Mysql';
$strings['mysqlcmd'] = 'Chemin vers le client mysql';
$strings['mysqldumpcms'] = 'Chemin vers la commande mysqldump';

$strings['sitenameinputerror'] = "Le nom de site est vide";
$strings['institutioninputerror'] = "L'institution est vide ou invalide";
$strings['rootwebinputerror'] = "L'URL d'acces est vide ou invalide";
$strings['databaseinputerror'] = "La base de données n'est pas définie";
$strings['coursefolderinputerror'] = "Le répertoire du cours n'est pas défini";

$strings['httpproxyhost'] = "Hôte Proxy HTTP";
$strings['httpproxyport'] = "Port Proxy HTTP";
$strings['httpproxybypass'] = "Filtre d'URL de proxy (exclusions)";
$strings['httpproxyuser'] = "Utilisateur Proxy";
$strings['httpproxypassword'] = "Mot de passe Proxy";

$strings['variable'] = 'Variable';
$strings['subkey'] = 'Clef';
$strings['category'] = 'Catégorie';
$strings['accessurl'] = 'Sous-site';
$strings['value'] = 'Valeur';
$strings['syncall'] = 'Synchroniser la sélection';
$strings['syncthis'] = 'Synchroniser ce réglage';

$strings['SiteNameExample'] = 'Exemple: Chamilo';
$strings['InstitutionExample'] = 'Exemple: Chamilo Association';
$strings['RootWebExample'] = 'Exemple: http://www.chamilo.org/';
$strings['DatabaseDescription'] = 'Une nouvelle base de données sera créée avec ce nom.';
$strings['RootWebExists'] = 'Une instance avec le même nom existe déjà.';
$strings['FromVersion'] = 'Version d\'origine';
$strings['CoursePath'] = 'Chemin vers répertoire de cours';
$strings['HomePath'] = 'Chemin vers répertoire home';
$strings['UploadPath'] = 'Chemin vers répertoire upload';

==> chamilo-1.11.32.zip: chamilo-1.11.32/plugin/vchamilo/lang/french.php <==
<?php
/**
 * @copyright (c) 2014 Valery Fremaux
 * @license GNU General Public License - http://www.gnu.org/copyleft/gpl.html
 * @author Valery Fremaux <valery.fremaux@gmail.com>
 */
$strings['archiverealroot'] = 'Container effectif de la cache (chemin réel sur disque)';
$strings['backtoindex'] = 'Retour aux instances';
$strings['cancel'] = 'Annuler';
$strings['choose'] = 'Choisir une action...';
$strings['closewindow'] = 'Fermer cette fenêtre';
$strings['continue'] = 'Continuer';
$strings['coursefolder'] = 'Répertoire des cours';
$strings['courserealroot'] = 'Container effectif de cours (chemin réel)';
$strings['clearcache'] = 'Vider le cache Twig';
$strings['clearmastercache'] = 'Vider le cache Twig du maître';
$strings['datalocation'] = 'Emplacement des données';
$strings['datapathavailable'] = 'Le répertoire de données est disponible : <br/>';
$strings['datapathnotavailable'] = 'Le répertoire de données existe mais a déjà des fichiers à l\'emplacement <br/>';
$strings['datapathcreated'] = 'Le répertoire de données a été créé :<br/>';
$strings['dbgroup'] = 'Réglages de base de données';
$strings['dbhost'] = 'Hôte de BdD';
$strings['dbpassword'] = 'Mot de passe';
$strings['dbprefix'] = 'Préfix de base';
$strings['dbuser'] = 'Utilisateur de BdD';
$strings['deleteinstances'] = "Désactiver";
$strings['destroyinstances'] = "Détruire";
$strings['edit'] = 'Modifier les paramètres';
$strings['emptysite'] = 'Nouveau site vide';
$strings['enable_virtualisation'] = 'Activer';
$strings['enabled'] = 'Etat';
$strings['enableinstances'] = "Activer";
$strings['enabling'] = 'Activation';
$strings['errormuststartwithcourses'] = 'Le répertoire de cours doit commencer par \'courses_\' pour éviter les collisions de chemin';
$strings['homerealroot'] = 'Container effectif de pages d\'accueil (chemin réel)';
$strings['hostdefinition'] = 'Définition d\'hôte';
$strings['hostlist'] = 'Les sites du réseau';
$strings['institution'] = 'Institution';
$strings['lastcron'] = 'Dernier cron';
$strings['maindatabase'] = 'Nom de BdD';
$strings['manage_instances'] = 'Aller au gestionnaire d\'instances';
$strings['sync_settings'] = 'Synchroniser des réglages';
$strings['deleteifempty'] = 'Supprimer la clef si vide';
$strings['newinstance'] = "Ajouter une instance";
$strings['no'] = 'Non';
$strings['plugin_comment'] = 'Permettre les chamilos virtuels.';
$strings['plugin_title'] = 'Virtualisation de Chamilo';
$strings['proxysettings'] = 'Réglages du Proxy';
$strings['registerinstance'] = "Enregistrer une instance";
$strings['rootweb'] = 'Racine Web';
$strings['savechanges'] = 'Enregistrer les modifications';
$strings['selectall'] = 'Selectionner tout';
$strings['selectnone'] = 'Déselectionner tout';
$strings['setconfigvalue'] = 'Mettre à jour une variable de configuration';
$strings['distributevalue'] = 'Distribuer la configuration';
$strings['sendconfigvalue'] = 'Distribution d\'une valeur de configuration';
$strings['singledatabase'] = 'Base de données unique';
$strings['sitename'] = 'Nom du site';
$strings['snapshotinstance'] = 'Snapshot';
$strings['snapshotmaster'] = 'Snapshot du Chamilo maître';
$strings['statisticsdatabase'] = 'base de données de statistiques';
$strings['successfinishedcapture'] = 'La capture de Chamilo est terminée';
$strings['tableprefix'] = 'Prefixe de table';
$strings['template'] = 'Modèle';
$strings['templating'] = 'Templating';
$strings['testconnection'] = "Test de la connexion";
$strings['testdatapath'] = "Test de l'emplacement de données";
$strings['userpersonaldatabase'] = 'base de données des données personnelles';
$strings['vchamilo'] = 'Chamilo Virtuel';
$strings['vchamilosnapshot1'] = 'ETAPE 1 DE 3 : Les répertoires de snapshot ont été créés. Continuer avec la capture des bases...';
$strings['vchamilosnapshot2'] = 'ETAPE 2 DE 3 : Les bases ont été capturées. Continuer avec la récupération des fichiers d\'usage... Attention, cette étape peut être longue si la plate-forme est fortement chargée en documents...';
$strings['vchamilosnapshot3'] = 'ETAPE 3 DE 3 : Fichiers capturés.';
$strings['withselection'] = "Avec la sélection : ";
$strings['yes'] = 'Oui';

$strings['mysqlcmds'] = 'Emplacement de la commande Mysql';
$strings['mysqlcmd'] = 'Chemin vers le client mysql';
$strings['mysqldumpcms'] = 'Chemin vers la commande mysqldump';

$strings['sitenameinputerror'] = "Le nom de site est vide";
$strings['institutioninputerror'] = "L'institution est vide ou invalide";
$strings['rootwebinputerror'] = "L'URL d'acces est vide ou invalide";
$strings['databaseinputerror'] = "La base de données n'est pas définie";
$strings['coursefolderinputerror'] = "Le répertoire du cours n'est pas défini";

$strings['httpproxyhost'] = "Hôte Proxy HTTP";
$strings['httpproxyport'] = "Port Proxy HTTP";
$strings['httpproxybypass'] = "Filtre d'URL de proxy (exclusions)";
$strings['httpproxyuser'] = "Utilisateur Proxy";
$strings['httpproxypassword'] = "Mot de passe Proxy";

$strings['variable'] = 'Variable';
$strings['subkey'] = 'Clef';
$strings['category'] = 'Catégorie';
$strings['accessurl'] = 'Sous-site';
$strings['value'] = 'Valeur';
$strings['syncall'] = 'Synchroniser la sélection';
$strings['syncthis'] = 'Synchroniser ce réglage';

$strings['SiteNameExample'] = 'Exemple: Chamilo';
$strings['InstitutionExample'] = 'Exemple: Chamilo Association';
$strings['RootWebExample'] = 'Exemple: http://www.chamilo.org/';
$strings['DatabaseDescription'] = 'Une nouvelle base de données sera créée avec ce nom.';
$strings['RootWebExists'] = 'Une instance avec le même nom existe déjà.';
$strings['FromVersion'] = 'Version d\'origine';
$strings['CoursePath'] = 'Chemin vers répertoire de cours';
$strings['HomePath'] = 'Chemin vers répertoire home';
$strings['UploadPath'] = 'Chemin vers répertoire upload';
